<?php

namespace App\Http\Controllers\User;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules\Password;

class ProfileController extends Controller
{

    public function avatar()
    {
        $pageTitle = "Profile Setting";
        $user      = auth()->user()->load('userRanking');
        return view($this->activeTemplate . 'user.profile_avatar', compact('pageTitle', 'user'));
    }

    public function submitAvatar(Request $request)
    {
         // Validate the uploaded file
        $request->validate([
            'file' => 'required|file|mimes:jpg,png,pdf|max:2048',
        ]);
        // Check if the file is valid
        if ($request->file('file')->isValid()) {
        // Store the file in the 'uploads' directory on the 'public' disk
        $filePath = $request->file('file')->store('uploads','public');
        // Return success response 
        $user = auth()->user();

        $user->profile = $filePath;
         
        $user->save();
        $notify[] = ['success', 'Avatar updated successfully'];
        return back()->withNotify($notify);

        }
        // Return error response
        $notify[] = ['error', 'Avatar update failed'];
        return back()->withNotify($notify);

          

    }


    public function profile()
    {
        $pageTitle = "Profile Setting";
        $user      = auth()->user()->load('userRanking');
        return view($this->activeTemplate . 'user.profile_setting', compact('pageTitle', 'user'));
    }

    public function submitProfile(Request $request)
    {
        $request->validate([
            'firstname' => 'required|string',
            'lastname'  => 'required|string',
        ], [
            'firstname.required' => 'First name field is required',
            'lastname.required'  => 'Last name field is required',
        ]);

        $user = auth()->user();

        $user->firstname = $request->firstname;
        $user->lastname  = $request->lastname;

        $user->address = [
            'address' => $request->address,
            'state'   => $request->state,
            'zip'     => $request->zip,
            'country' => @$user->address->country,
            'city'    => $request->city,
        ];

        $user->save();
        $notify[] = ['success', 'Profile updated successfully'];
        return back()->withNotify($notify);
    }

    public function changePassword()
    {
        $pageTitle = 'Change Password';
        return view($this->activeTemplate . 'user.password', compact('pageTitle'));
    }

    public function submitPassword(Request $request)
    {
        $passwordValidation = Password::min(6);
        if (gs('secure_password')) {
            $passwordValidation = $passwordValidation->mixedCase()->numbers()->symbols()->uncompromised();
        }

        $this->validate($request, [
            'current_password' => 'required',
            'password'         => ['required', 'confirmed', $passwordValidation],
        ]);

        $user = auth()->user();
        if (Hash::check($request->current_password, $user->password)) {
            $password       = Hash::make($request->password);
            $user->password = $password;
            $user->save();
            $notify[] = ['success', 'Password changes successfully'];
            return back()->withNotify($notify);
        } else {
            $notify[] = ['error', 'The password doesn\'t match!'];
            return back()->withNotify($notify);
        }
    }
}
